@@ -1,7 +1,15 @@
 from .certificate_manager import CertificateManagerCertificateNameTag
-from .cloud_front import CloudfrontDistributionComment, CloudfrontDistributionLogging
+from .cloud_front import (
+    CloudfrontDistributionComment,
+    CloudfrontDistributionLogging,
+    CloudfrontDistributionResponseHeadersPolicy,
+    CloudfrontResponseHeaderConfigLongHstsMaxAge,
+)
 from .code_build import CodeBuildProjectCloudWatchLogs
-from .ecs import EcsServiceFargatePlatformVersionNotOutdated
+from .ecs import (
+    EcsServiceDeploymentConfiguration,
+    EcsServiceFargatePlatformVersionNotOutdated,
+)
 from .intrinsic_function import IntrinsicFunctionSubUnresolvedObject
 from .metadata import MetadataAxChangesetAutoApprove
 from .s3 import S3BucketEncryption, S3BucketPublicAccess
@@ -10,7 +18,10 @@ __all__ = [
     "CertificateManagerCertificateNameTag",
     "CloudfrontDistributionComment",
     "CloudfrontDistributionLogging",
+    "CloudfrontDistributionResponseHeadersPolicy",
+    "CloudfrontResponseHeaderConfigLongHstsMaxAge",
     "CodeBuildProjectCloudWatchLogs",
+    "EcsServiceDeploymentConfiguration",
     "EcsServiceFargatePlatformVersionNotOutdated",
     "IntrinsicFunctionSubUnresolvedObject",
     "MetadataAxChangesetAutoApprove",
